import { SQS } from '@aws-sdk/client-sqs';
import { Response, Headers, Request, handleHTTPRequest, handleQueuedJob, LocalStorage } from 'queue-run';
import { URL, URLSearchParams } from 'url';
import invariant from 'tiny-invariant';

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
  try {
    var info = gen[key](arg);
    var value = info.value;
  } catch (error) {
    reject(error);
    return;
  }

  if (info.done) {
    resolve(value);
  } else {
    Promise.resolve(value).then(_next, _throw);
  }
}

function _asyncToGenerator(fn) {
  return function () {
    var self = this,
        args = arguments;
    return new Promise(function (resolve, reject) {
      var gen = fn.apply(self, args);

      function _next(value) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
      }

      function _throw(err) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
      }

      _next(undefined);
    });
  };
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _inheritsLoose(subClass, superClass) {
  subClass.prototype = Object.create(superClass.prototype);
  subClass.prototype.constructor = subClass;

  _setPrototypeOf(subClass, superClass);
}

function _setPrototypeOf(o, p) {
  _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
    o.__proto__ = p;
    return o;
  };

  return _setPrototypeOf(o, p);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var runtime = {exports: {}};

/**
 * Copyright (c) 2014-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

(function (module) {
  var runtime = /*#__PURE__*/function (exports) {

    var Op = Object.prototype;
    var hasOwn = Op.hasOwnProperty;
    var undefined$1; // More compressible than void 0.

    var $Symbol = typeof Symbol === "function" ? Symbol : {};
    var iteratorSymbol = $Symbol.iterator || "@@iterator";
    var asyncIteratorSymbol = $Symbol.asyncIterator || "@@asyncIterator";
    var toStringTagSymbol = $Symbol.toStringTag || "@@toStringTag";

    function define(obj, key, value) {
      Object.defineProperty(obj, key, {
        value: value,
        enumerable: true,
        configurable: true,
        writable: true
      });
      return obj[key];
    }

    try {
      // IE 8 has a broken Object.defineProperty that only works on DOM objects.
      define({}, "");
    } catch (err) {
      define = function define(obj, key, value) {
        return obj[key] = value;
      };
    }

    function wrap(innerFn, outerFn, self, tryLocsList) {
      // If outerFn provided and outerFn.prototype is a Generator, then outerFn.prototype instanceof Generator.
      var protoGenerator = outerFn && outerFn.prototype instanceof Generator ? outerFn : Generator;
      var generator = Object.create(protoGenerator.prototype);
      var context = new Context(tryLocsList || []); // The ._invoke method unifies the implementations of the .next,
      // .throw, and .return methods.

      generator._invoke = makeInvokeMethod(innerFn, self, context);
      return generator;
    }

    exports.wrap = wrap; // Try/catch helper to minimize deoptimizations. Returns a completion
    // record like context.tryEntries[i].completion. This interface could
    // have been (and was previously) designed to take a closure to be
    // invoked without arguments, but in all the cases we care about we
    // already have an existing method we want to call, so there's no need
    // to create a new function object. We can even get away with assuming
    // the method takes exactly one argument, since that happens to be true
    // in every case, so we don't have to touch the arguments object. The
    // only additional allocation required is the completion record, which
    // has a stable shape and so hopefully should be cheap to allocate.

    function tryCatch(fn, obj, arg) {
      try {
        return {
          type: "normal",
          arg: fn.call(obj, arg)
        };
      } catch (err) {
        return {
          type: "throw",
          arg: err
        };
      }
    }

    var GenStateSuspendedStart = "suspendedStart";
    var GenStateSuspendedYield = "suspendedYield";
    var GenStateExecuting = "executing";
    var GenStateCompleted = "completed"; // Returning this object from the innerFn has the same effect as
    // breaking out of the dispatch switch statement.

    var ContinueSentinel = {}; // Dummy constructor functions that we use as the .constructor and
    // .constructor.prototype properties for functions that return Generator
    // objects. For full spec compliance, you may wish to configure your
    // minifier not to mangle the names of these two functions.

    function Generator() {}

    function GeneratorFunction() {}

    function GeneratorFunctionPrototype() {} // This is a polyfill for %IteratorPrototype% for environments that
    // don't natively support it.


    var IteratorPrototype = {};
    define(IteratorPrototype, iteratorSymbol, function () {
      return this;
    });
    var getProto = Object.getPrototypeOf;
    var NativeIteratorPrototype = getProto && /*#__PURE__*/getProto( /*#__PURE__*/getProto( /*#__PURE__*/values([])));

    if (NativeIteratorPrototype && NativeIteratorPrototype !== Op && hasOwn.call(NativeIteratorPrototype, iteratorSymbol)) {
      // This environment has a native %IteratorPrototype%; use it instead
      // of the polyfill.
      IteratorPrototype = NativeIteratorPrototype;
    }

    var Gp = GeneratorFunctionPrototype.prototype = Generator.prototype = /*#__PURE__*/Object.create(IteratorPrototype);
    GeneratorFunction.prototype = GeneratorFunctionPrototype;
    define(Gp, "constructor", GeneratorFunctionPrototype);
    define(GeneratorFunctionPrototype, "constructor", GeneratorFunction);
    GeneratorFunction.displayName = /*#__PURE__*/define(GeneratorFunctionPrototype, toStringTagSymbol, "GeneratorFunction"); // Helper for defining the .next, .throw, and .return methods of the
    // Iterator interface in terms of a single ._invoke method.

    function defineIteratorMethods(prototype) {
      ["next", "throw", "return"].forEach(function (method) {
        define(prototype, method, function (arg) {
          return this._invoke(method, arg);
        });
      });
    }

    exports.isGeneratorFunction = function (genFun) {
      var ctor = typeof genFun === "function" && genFun.constructor;
      return ctor ? ctor === GeneratorFunction || // For the native GeneratorFunction constructor, the best we can
      // do is to check its .name property.
      (ctor.displayName || ctor.name) === "GeneratorFunction" : false;
    };

    exports.mark = function (genFun) {
      if (Object.setPrototypeOf) {
        Object.setPrototypeOf(genFun, GeneratorFunctionPrototype);
      } else {
        genFun.__proto__ = GeneratorFunctionPrototype;
        define(genFun, toStringTagSymbol, "GeneratorFunction");
      }

      genFun.prototype = Object.create(Gp);
      return genFun;
    }; // Within the body of any async function, `await x` is transformed to
    // `yield regeneratorRuntime.awrap(x)`, so that the runtime can test
    // `hasOwn.call(value, "__await")` to determine if the yielded value is
    // meant to be awaited.


    exports.awrap = function (arg) {
      return {
        __await: arg
      };
    };

    function AsyncIterator(generator, PromiseImpl) {
      function invoke(method, arg, resolve, reject) {
        var record = tryCatch(generator[method], generator, arg);

        if (record.type === "throw") {
          reject(record.arg);
        } else {
          var result = record.arg;
          var value = result.value;

          if (value && typeof value === "object" && hasOwn.call(value, "__await")) {
            return PromiseImpl.resolve(value.__await).then(function (value) {
              invoke("next", value, resolve, reject);
            }, function (err) {
              invoke("throw", err, resolve, reject);
            });
          }

          return PromiseImpl.resolve(value).then(function (unwrapped) {
            // When a yielded Promise is resolved, its final value becomes
            // the .value of the Promise<{value,done}> result for the
            // current iteration.
            result.value = unwrapped;
            resolve(result);
          }, function (error) {
            // If a rejected Promise was yielded, throw the rejection back
            // into the async generator function so it can be handled there.
            return invoke("throw", error, resolve, reject);
          });
        }
      }

      var previousPromise;

      function enqueue(method, arg) {
        function callInvokeWithMethodAndArg() {
          return new PromiseImpl(function (resolve, reject) {
            invoke(method, arg, resolve, reject);
          });
        }

        return previousPromise = // If enqueue has been called before, then we want to wait until
        // all previous Promises have been resolved before calling invoke,
        // so that results are always delivered in the correct order. If
        // enqueue has not been called before, then it is important to
        // call invoke immediately, without waiting on a callback to fire,
        // so that the async generator function has the opportunity to do
        // any necessary setup in a predictable way. This predictability
        // is why the Promise constructor synchronously invokes its
        // executor callback, and why async functions synchronously
        // execute code before the first await. Since we implement simple
        // async functions in terms of async generators, it is especially
        // important to get this right, even though it requires care.
        previousPromise ? previousPromise.then(callInvokeWithMethodAndArg, // Avoid propagating failures to Promises returned by later
        // invocations of the iterator.
        callInvokeWithMethodAndArg) : callInvokeWithMethodAndArg();
      } // Define the unified helper method that is used to implement .next,
      // .throw, and .return (see defineIteratorMethods).


      this._invoke = enqueue;
    }

    defineIteratorMethods(AsyncIterator.prototype);
    define(AsyncIterator.prototype, asyncIteratorSymbol, function () {
      return this;
    });
    exports.AsyncIterator = AsyncIterator; // Note that simple async functions are implemented on top of
    // AsyncIterator objects; they just return a Promise for the value of
    // the final result produced by the iterator.

    exports.async = function (innerFn, outerFn, self, tryLocsList, PromiseImpl) {
      if (PromiseImpl === void 0) PromiseImpl = Promise;
      var iter = new AsyncIterator(wrap(innerFn, outerFn, self, tryLocsList), PromiseImpl);
      return exports.isGeneratorFunction(outerFn) ? iter // If outerFn is a generator, return the full iterator.
      : iter.next().then(function (result) {
        return result.done ? result.value : iter.next();
      });
    };

    function makeInvokeMethod(innerFn, self, context) {
      var state = GenStateSuspendedStart;
      return function invoke(method, arg) {
        if (state === GenStateExecuting) {
          throw new Error("Generator is already running");
        }

        if (state === GenStateCompleted) {
          if (method === "throw") {
            throw arg;
          } // Be forgiving, per 25.3.3.3.3 of the spec:
          // https://people.mozilla.org/~jorendorff/es6-draft.html#sec-generatorresume


          return doneResult();
        }

        context.method = method;
        context.arg = arg;

        while (true) {
          var delegate = context.delegate;

          if (delegate) {
            var delegateResult = maybeInvokeDelegate(delegate, context);

            if (delegateResult) {
              if (delegateResult === ContinueSentinel) continue;
              return delegateResult;
            }
          }

          if (context.method === "next") {
            // Setting context._sent for legacy support of Babel's
            // function.sent implementation.
            context.sent = context._sent = context.arg;
          } else if (context.method === "throw") {
            if (state === GenStateSuspendedStart) {
              state = GenStateCompleted;
              throw context.arg;
            }

            context.dispatchException(context.arg);
          } else if (context.method === "return") {
            context.abrupt("return", context.arg);
          }

          state = GenStateExecuting;
          var record = tryCatch(innerFn, self, context);

          if (record.type === "normal") {
            // If an exception is thrown from innerFn, we leave state ===
            // GenStateExecuting and loop back for another invocation.
            state = context.done ? GenStateCompleted : GenStateSuspendedYield;

            if (record.arg === ContinueSentinel) {
              continue;
            }

            return {
              value: record.arg,
              done: context.done
            };
          } else if (record.type === "throw") {
            state = GenStateCompleted; // Dispatch the exception by looping back around to the
            // context.dispatchException(context.arg) call above.

            context.method = "throw";
            context.arg = record.arg;
          }
        }
      };
    } // Call delegate.iterator[context.method](context.arg) and handle the
    // result, either by returning a { value, done } result from the
    // delegate iterator, or by modifying context.method and context.arg,
    // setting context.delegate to null, and returning the ContinueSentinel.


    function maybeInvokeDelegate(delegate, context) {
      var method = delegate.iterator[context.method];

      if (method === undefined$1) {
        // A .throw or .return when the delegate iterator has no .throw
        // method always terminates the yield* loop.
        context.delegate = null;

        if (context.method === "throw") {
          // Note: ["return"] must be used for ES3 parsing compatibility.
          if (delegate.iterator["return"]) {
            // If the delegate iterator has a return method, give it a
            // chance to clean up.
            context.method = "return";
            context.arg = undefined$1;
            maybeInvokeDelegate(delegate, context);

            if (context.method === "throw") {
              // If maybeInvokeDelegate(context) changed context.method from
              // "return" to "throw", let that override the TypeError below.
              return ContinueSentinel;
            }
          }

          context.method = "throw";
          context.arg = new TypeError("The iterator does not provide a 'throw' method");
        }

        return ContinueSentinel;
      }

      var record = tryCatch(method, delegate.iterator, context.arg);

      if (record.type === "throw") {
        context.method = "throw";
        context.arg = record.arg;
        context.delegate = null;
        return ContinueSentinel;
      }

      var info = record.arg;

      if (!info) {
        context.method = "throw";
        context.arg = new TypeError("iterator result is not an object");
        context.delegate = null;
        return ContinueSentinel;
      }

      if (info.done) {
        // Assign the result of the finished delegate to the temporary
        // variable specified by delegate.resultName (see delegateYield).
        context[delegate.resultName] = info.value; // Resume execution at the desired location (see delegateYield).

        context.next = delegate.nextLoc; // If context.method was "throw" but the delegate handled the
        // exception, let the outer generator proceed normally. If
        // context.method was "next", forget context.arg since it has been
        // "consumed" by the delegate iterator. If context.method was
        // "return", allow the original .return call to continue in the
        // outer generator.

        if (context.method !== "return") {
          context.method = "next";
          context.arg = undefined$1;
        }
      } else {
        // Re-yield the result returned by the delegate method.
        return info;
      } // The delegate iterator is finished, so forget it and continue with
      // the outer generator.


      context.delegate = null;
      return ContinueSentinel;
    } // Define Generator.prototype.{next,throw,return} in terms of the
    // unified ._invoke helper method.


    defineIteratorMethods(Gp);
    define(Gp, toStringTagSymbol, "Generator"); // A Generator should always return itself as the iterator object when the
    // @@iterator function is called on it. Some browsers' implementations of the
    // iterator prototype chain incorrectly implement this, causing the Generator
    // object to not be returned from this call. This ensures that doesn't happen.
    // See https://github.com/facebook/regenerator/issues/274 for more details.

    define(Gp, iteratorSymbol, function () {
      return this;
    });
    define(Gp, "toString", function () {
      return "[object Generator]";
    });

    function pushTryEntry(locs) {
      var entry = {
        tryLoc: locs[0]
      };

      if (1 in locs) {
        entry.catchLoc = locs[1];
      }

      if (2 in locs) {
        entry.finallyLoc = locs[2];
        entry.afterLoc = locs[3];
      }

      this.tryEntries.push(entry);
    }

    function resetTryEntry(entry) {
      var record = entry.completion || {};
      record.type = "normal";
      delete record.arg;
      entry.completion = record;
    }

    function Context(tryLocsList) {
      // The root entry object (effectively a try statement without a catch
      // or a finally block) gives us a place to store values thrown from
      // locations where there is no enclosing try statement.
      this.tryEntries = [{
        tryLoc: "root"
      }];
      tryLocsList.forEach(pushTryEntry, this);
      this.reset(true);
    }

    exports.keys = function (object) {
      var keys = [];

      for (var key in object) {
        keys.push(key);
      }

      keys.reverse(); // Rather than returning an object with a next method, we keep
      // things simple and return the next function itself.

      return function next() {
        while (keys.length) {
          var key = keys.pop();

          if (key in object) {
            next.value = key;
            next.done = false;
            return next;
          }
        } // To avoid creating an additional object, we just hang the .value
        // and .done properties off the next function object itself. This
        // also ensures that the minifier will not anonymize the function.


        next.done = true;
        return next;
      };
    };

    function values(iterable) {
      if (iterable) {
        var iteratorMethod = iterable[iteratorSymbol];

        if (iteratorMethod) {
          return iteratorMethod.call(iterable);
        }

        if (typeof iterable.next === "function") {
          return iterable;
        }

        if (!isNaN(iterable.length)) {
          var i = -1,
              next = function next() {
            while (++i < iterable.length) {
              if (hasOwn.call(iterable, i)) {
                next.value = iterable[i];
                next.done = false;
                return next;
              }
            }

            next.value = undefined$1;
            next.done = true;
            return next;
          };

          return next.next = next;
        }
      } // Return an iterator with no values.


      return {
        next: doneResult
      };
    }

    exports.values = values;

    function doneResult() {
      return {
        value: undefined$1,
        done: true
      };
    }

    Context.prototype = {
      constructor: Context,
      reset: function reset(skipTempReset) {
        this.prev = 0;
        this.next = 0; // Resetting context._sent for legacy support of Babel's
        // function.sent implementation.

        this.sent = this._sent = undefined$1;
        this.done = false;
        this.delegate = null;
        this.method = "next";
        this.arg = undefined$1;
        this.tryEntries.forEach(resetTryEntry);

        if (!skipTempReset) {
          for (var name in this) {
            // Not sure about the optimal order of these conditions:
            if (name.charAt(0) === "t" && hasOwn.call(this, name) && !isNaN(+name.slice(1))) {
              this[name] = undefined$1;
            }
          }
        }
      },
      stop: function stop() {
        this.done = true;
        var rootEntry = this.tryEntries[0];
        var rootRecord = rootEntry.completion;

        if (rootRecord.type === "throw") {
          throw rootRecord.arg;
        }

        return this.rval;
      },
      dispatchException: function dispatchException(exception) {
        if (this.done) {
          throw exception;
        }

        var context = this;

        function handle(loc, caught) {
          record.type = "throw";
          record.arg = exception;
          context.next = loc;

          if (caught) {
            // If the dispatched exception was caught by a catch block,
            // then let that catch block handle the exception normally.
            context.method = "next";
            context.arg = undefined$1;
          }

          return !!caught;
        }

        for (var i = this.tryEntries.length - 1; i >= 0; --i) {
          var entry = this.tryEntries[i];
          var record = entry.completion;

          if (entry.tryLoc === "root") {
            // Exception thrown outside of any try block that could handle
            // it, so set the completion value of the entire function to
            // throw the exception.
            return handle("end");
          }

          if (entry.tryLoc <= this.prev) {
            var hasCatch = hasOwn.call(entry, "catchLoc");
            var hasFinally = hasOwn.call(entry, "finallyLoc");

            if (hasCatch && hasFinally) {
              if (this.prev < entry.catchLoc) {
                return handle(entry.catchLoc, true);
              } else if (this.prev < entry.finallyLoc) {
                return handle(entry.finallyLoc);
              }
            } else if (hasCatch) {
              if (this.prev < entry.catchLoc) {
                return handle(entry.catchLoc, true);
              }
            } else if (hasFinally) {
              if (this.prev < entry.finallyLoc) {
                return handle(entry.finallyLoc);
              }
            } else {
              throw new Error("try statement without catch or finally");
            }
          }
        }
      },
      abrupt: function abrupt(type, arg) {
        for (var i = this.tryEntries.length - 1; i >= 0; --i) {
          var entry = this.tryEntries[i];

          if (entry.tryLoc <= this.prev && hasOwn.call(entry, "finallyLoc") && this.prev < entry.finallyLoc) {
            var finallyEntry = entry;
            break;
          }
        }

        if (finallyEntry && (type === "break" || type === "continue") && finallyEntry.tryLoc <= arg && arg <= finallyEntry.finallyLoc) {
          // Ignore the finally entry if control is not jumping to a
          // location outside the try/catch block.
          finallyEntry = null;
        }

        var record = finallyEntry ? finallyEntry.completion : {};
        record.type = type;
        record.arg = arg;

        if (finallyEntry) {
          this.method = "next";
          this.next = finallyEntry.finallyLoc;
          return ContinueSentinel;
        }

        return this.complete(record);
      },
      complete: function complete(record, afterLoc) {
        if (record.type === "throw") {
          throw record.arg;
        }

        if (record.type === "break" || record.type === "continue") {
          this.next = record.arg;
        } else if (record.type === "return") {
          this.rval = this.arg = record.arg;
          this.method = "return";
          this.next = "end";
        } else if (record.type === "normal" && afterLoc) {
          this.next = afterLoc;
        }

        return ContinueSentinel;
      },
      finish: function finish(finallyLoc) {
        for (var i = this.tryEntries.length - 1; i >= 0; --i) {
          var entry = this.tryEntries[i];

          if (entry.finallyLoc === finallyLoc) {
            this.complete(entry.completion, entry.afterLoc);
            resetTryEntry(entry);
            return ContinueSentinel;
          }
        }
      },
      "catch": function _catch(tryLoc) {
        for (var i = this.tryEntries.length - 1; i >= 0; --i) {
          var entry = this.tryEntries[i];

          if (entry.tryLoc === tryLoc) {
            var record = entry.completion;

            if (record.type === "throw") {
              var thrown = record.arg;
              resetTryEntry(entry);
            }

            return thrown;
          }
        } // The context.catch method must only be called with a location
        // argument that corresponds to a known catch block.


        throw new Error("illegal catch attempt");
      },
      delegateYield: function delegateYield(iterable, resultName, nextLoc) {
        this.delegate = {
          iterator: values(iterable),
          resultName: resultName,
          nextLoc: nextLoc
        };

        if (this.method === "next") {
          // Deliberately forget the last sent value so that we don't
          // accidentally pass it on to the delegate.
          this.arg = undefined$1;
        }

        return ContinueSentinel;
      }
    }; // Regardless of whether this script is executing as a CommonJS module
    // or not, return the runtime object so that we can declare the variable
    // regeneratorRuntime in the outer scope, which allows this module to be
    // injected easily by `bin/regenerator --include-runtime script.js`.

    return exports;
  }( // If this script is executing as a CommonJS module, use module.exports
  // as the regeneratorRuntime namespace. Otherwise create a new empty
  // object. Either way, the resulting object will be used to initialize
  // the regeneratorRuntime variable at the top of this file.
  module.exports );

  try {
    regeneratorRuntime = runtime;
  } catch (accidentalStrictMode) {
    // This module should not be running in strict mode, so the above
    // assignment should always work unless something is misconfigured. Just
    // in case runtime.js accidentally runs in strict mode, in modern engines
    // we can explicitly access globalThis. In older engines we can escape
    // strict mode using a global Function call. This could conceivably fail
    // if a Content Security Policy forbids using Function, but in that case
    // the proper solution is to fix the accidental strict mode problem. If
    // you've misconfigured your bundler to force strict mode and applied a
    // CSP to forbid Function, and you're not willing to fix either of those
    // problems, please detail your unique predicament in a GitHub issue.
    if (typeof globalThis === "object") {
      globalThis.regeneratorRuntime = runtime;
    } else {
      Function("r", "regeneratorRuntime = r")(runtime);
    }
  }
})(runtime);

var _regeneratorRuntime = runtime.exports;

// This function swaps AWS environment variables.
//
// We allow backend function to set their own AWS variables (access key,
// session, region, etc).  We also have our own variables, which we need to
// access various resources (queues, database, logging, etc).
//
// When building the backend, we alias the user's AWS environment variables, so
// they don't get overwritten by AWS.
//
// When the backend starts, we extract the AWS environment variables we need, and
// turn those into client configuration object (returned from this function).
//
// Then we un-alias from user's AWS environment variables.
function swapAWSEnvVars() {
  var _credentials = {
    sessionToken: process.env.AWS_SESSION_TOKEN,
    accessKeyId: process.env.AWS_ACCESS_KEY_ID,
    secretAccessKey: process.env.AWS_SECRET_ACCESS_KEY
  };
  var region = process.env.AWS_REGION; // Allow backend function to bring their own AWS environment variables.
  // Our AWS access is of no use to them.
  //
  // These were aliased when the Lambda function was created, so they won't
  // conflict with environment variables set by AWS.

  var aliasPrefix = "ALIASED_FOR_CLIENT__";

  for (var _i = 0, _arr = ["AWS_SESSION_TOKEN", "AWS_ACCESS_KEY_ID", "AWS_SECRET_ACCESS_KEY", "AWS_REGION"]; _i < _arr.length; _i++) {
    var key = _arr[_i];
    var aliased = process.env[aliasPrefix + key];
    if (aliased) process.env[key] = aliased;else delete process.env[key];
  }

  var slug = process.env.AWS_LAMBDA_FUNCTION_NAME;
  return {
    credentials: function () {
      var _credentials2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                return _context.abrupt("return", _credentials);

              case 1:
              case "end":
                return _context.stop();
            }
          }
        }, _callee);
      }));

      function credentials() {
        return _credentials2.apply(this, arguments);
      }

      return credentials;
    }(),
    region: region,
    slug: slug
  };
}

function httpHandler(_x, _x2) {
  return _httpHandler.apply(this, arguments);
}

function _httpHandler() {
  _httpHandler = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(event, newLocalStorage) {
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.next = 2;
            return asFetchRequest(event, /*#__PURE__*/function () {
              var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(request) {
                return _regeneratorRuntime.wrap(function _callee$(_context) {
                  while (1) {
                    switch (_context.prev = _context.next) {
                      case 0:
                        return _context.abrupt("return", handleHTTPRequest(request, newLocalStorage));

                      case 1:
                      case "end":
                        return _context.stop();
                    }
                  }
                }, _callee);
              }));

              return function (_x7) {
                return _ref.apply(this, arguments);
              };
            }());

          case 2:
            return _context2.abrupt("return", _context2.sent);

          case 3:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  }));
  return _httpHandler.apply(this, arguments);
}

function asFetchRequest(_x3, _x4) {
  return _asFetchRequest.apply(this, arguments);
}

function _asFetchRequest() {
  _asFetchRequest = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3(event, // eslint-disable-next-line no-unused-vars
  handler) {
    var request, response, _error$status, message;

    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            request = toFetchRequest(event);
            _context3.prev = 1;
            _context3.next = 4;
            return handler(request);

          case 4:
            response = _context3.sent;
            return _context3.abrupt("return", fromFetchResponse(request, toFetchResponse(request, response)));

          case 8:
            _context3.prev = 8;
            _context3.t0 = _context3["catch"](1);

            if (!(_context3.t0 instanceof Response)) {
              _context3.next = 14;
              break;
            }

            return _context3.abrupt("return", fromFetchResponse(request, new Response(_context3.t0.body, _extends({}, _context3.t0, {
              status: (_error$status = _context3.t0.status) != null ? _error$status : 500
            }))));

          case 14:
            console.error("Callback error", _context3.t0);
            message = _context3.t0 instanceof Error ? _context3.t0.message : String(_context3.t0);
            return _context3.abrupt("return", fromFetchResponse(request, new Response(message, {
              status: 500
            })));

          case 17:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3, null, [[1, 8]]);
  }));
  return _asFetchRequest.apply(this, arguments);
}

function toFetchRequest(event) {
  if ("requestContext" in event) {
    var http = event.requestContext.http;
    console.info('[%s] %s %s %s "%s%"', http.sourceIp, http.protocol, http.method, http.path, http.userAgent);
    var method = http.method;
    var url = new URL("https://" + event.requestContext.domainName + event.rawPath + "?" + event.rawQueryString).href;
    var headers = new Headers(event.headers);
    if (event.cookies) headers.set("Cookie", event.cookies.join(";"));
    var hasBody = method !== "GET" && method !== "HEAD";
    var body = hasBody ? event.body && event.isBase64Encoded ? Buffer.from(event.body, "base64") : event.body : undefined;
    return new Request(url, {
      body: body,
      headers: headers,
      method: method
    });
  } else {
    var _headers = event.headers,
        _method = event.method,
        _url = event.url;

    var _hasBody = _method !== "GET" && _method !== "HEAD";

    var _body = _hasBody && event.body ? Buffer.from(event.body, "base64") : undefined;

    return new Request(_url, {
      body: _body,
      headers: _headers,
      method: _method
    });
  }
}

function toFetchResponse(request, response) {
  if (response instanceof Response) {
    var _response$status;

    var body = request.method === "HEAD" ? "" : response.body;
    return new Response(body, {
      headers: response.headers,
      status: (_response$status = response.status) != null ? _response$status : 200
    });
  }

  if (typeof response === "string" || response instanceof String) {
    return new Response(String(response), {
      headers: {
        "Content-Type": "text/plain; charset=utf-8"
      }
    });
  }

  if (response instanceof Buffer) {
    return new Response(response, {
      headers: {
        "Content-Type": "text/plain"
      }
    });
  }

  if (response === null || response === undefined) {
    if (request.method !== "HEAD") {
      console.error("HTTP request returned null or undefined. If this was intentional, use this instead: return new Response(null)");
    }

    return new Response(undefined, {
      status: 204
    });
  }

  return new Response(JSON.stringify(response), {
    headers: {
      "Content-Type": "application/json"
    }
  });
}

function fromFetchResponse(_x5, _x6) {
  return _fromFetchResponse.apply(this, arguments);
}

function _fromFetchResponse() {
  _fromFetchResponse = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4(request, response) {
    var _response$status2;

    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            if (!(response.status === 204)) {
              _context4.next = 4;
              break;
            }

            _context4.t0 = "";
            _context4.next = 7;
            break;

          case 4:
            _context4.next = 6;
            return response.buffer();

          case 6:
            _context4.t0 = _context4.sent.toString("base64");

          case 7:
            _context4.t1 = _context4.t0;
            _context4.t2 = Object.fromEntries(Array.from(response.headers.entries()));
            _context4.t3 = (_response$status2 = response.status) != null ? _response$status2 : 200;
            return _context4.abrupt("return", {
              body: _context4.t1,
              isBase64Encoded: true,
              headers: _context4.t2,
              statusCode: _context4.t3
            });

          case 11:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  }));
  return _fromFetchResponse.apply(this, arguments);
}

function handleSQSMessages(_x) {
  return _handleSQSMessages.apply(this, arguments);
} // We follow the convention that FIFO queues end with .fifo.

function _handleSQSMessages() {
  _handleSQSMessages = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(_ref) {
    var getRemainingTimeInMillis, messages, newLocalStorage, sqs;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            getRemainingTimeInMillis = _ref.getRemainingTimeInMillis, messages = _ref.messages, newLocalStorage = _ref.newLocalStorage, sqs = _ref.sqs;

            if (!isFifoQueue(messages[0])) {
              _context.next = 7;
              break;
            }

            _context.next = 4;
            return handleFifoMessages({
              getRemainingTimeInMillis: getRemainingTimeInMillis,
              messages: messages,
              newLocalStorage: newLocalStorage,
              sqs: sqs
            });

          case 4:
            _context.t0 = _context.sent;
            _context.next = 10;
            break;

          case 7:
            _context.next = 9;
            return handleStandardMessages({
              getRemainingTimeInMillis: getRemainingTimeInMillis,
              messages: messages,
              newLocalStorage: newLocalStorage,
              sqs: sqs
            });

          case 9:
            _context.t0 = _context.sent;

          case 10:
            return _context.abrupt("return", _context.t0);

          case 11:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));
  return _handleSQSMessages.apply(this, arguments);
}

function isFifoQueue(message) {
  return getQueueName(message).endsWith(".fifo");
} // Standard queue: we can process the batch of messages in an order.
// Returns IDs of messages that failed to process.


function handleStandardMessages(_x2) {
  return _handleStandardMessages.apply(this, arguments);
} // FIFO queue: we get a batch of message from the same group.
// Process messages in order, fail on the first message that fails, and
// return that and all subsequent message IDs.


function _handleStandardMessages() {
  _handleStandardMessages = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3(_ref2) {
    var getRemainingTimeInMillis, messages, newLocalStorage, sqs, remainingTime, failedMessageIds;
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            getRemainingTimeInMillis = _ref2.getRemainingTimeInMillis, messages = _ref2.messages, newLocalStorage = _ref2.newLocalStorage, sqs = _ref2.sqs;
            remainingTime = getRemainingTimeInMillis();
            _context3.next = 4;
            return Promise.all(messages.map( /*#__PURE__*/function () {
              var _ref6 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(message) {
                var successful;
                return _regeneratorRuntime.wrap(function _callee2$(_context2) {
                  while (1) {
                    switch (_context2.prev = _context2.next) {
                      case 0:
                        _context2.next = 2;
                        return handleOneSQSMessage({
                          message: message,
                          newLocalStorage: newLocalStorage,
                          sqs: sqs,
                          remainingTime: remainingTime
                        });

                      case 2:
                        successful = _context2.sent;
                        return _context2.abrupt("return", successful ? null : message.messageId);

                      case 4:
                      case "end":
                        return _context2.stop();
                    }
                  }
                }, _callee2);
              }));

              return function (_x5) {
                return _ref6.apply(this, arguments);
              };
            }()));

          case 4:
            failedMessageIds = _context3.sent;
            return _context3.abrupt("return", {
              batchItemFailures: failedMessageIds.filter(Boolean).map(function (id) {
                return {
                  itemIdentifier: id
                };
              })
            });

          case 6:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  }));
  return _handleStandardMessages.apply(this, arguments);
}

function handleFifoMessages(_x3) {
  return _handleFifoMessages.apply(this, arguments);
}

function _handleFifoMessages() {
  _handleFifoMessages = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4(_ref3) {
    var getRemainingTimeInMillis, messages, newLocalStorage, sqs, next, message, remainingTime, successful;
    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            getRemainingTimeInMillis = _ref3.getRemainingTimeInMillis, messages = _ref3.messages, newLocalStorage = _ref3.newLocalStorage, sqs = _ref3.sqs;

          case 1:
            if (!(next = messages.shift())) {
              _context4.next = 11;
              break;
            }

            message = next;
            remainingTime = getRemainingTimeInMillis();
            _context4.next = 6;
            return handleOneSQSMessage({
              message: message,
              newLocalStorage: newLocalStorage,
              sqs: sqs,
              remainingTime: remainingTime
            });

          case 6:
            successful = _context4.sent;

            if (successful) {
              _context4.next = 9;
              break;
            }

            return _context4.abrupt("return", {
              batchItemFailures: [next].concat(messages).map(function (message) {
                return {
                  itemIdentifier: message.messageId
                };
              })
            });

          case 9:
            _context4.next = 1;
            break;

          case 11:
            return _context4.abrupt("return", {
              batchItemFailures: []
            });

          case 12:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  }));
  return _handleFifoMessages.apply(this, arguments);
}

function handleOneSQSMessage(_x4) {
  return _handleOneSQSMessage.apply(this, arguments);
} // Gets the full queue URL from the ARN.  API needs the URL, not ARN.

function _handleOneSQSMessage() {
  _handleOneSQSMessage = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5(_ref4) {
    var message, newLocalStorage, remainingTime, sqs, queueName, successful;
    return _regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            message = _ref4.message, newLocalStorage = _ref4.newLocalStorage, remainingTime = _ref4.remainingTime, sqs = _ref4.sqs;
            queueName = getQueueName(message);
            _context5.next = 4;
            return handleQueuedJob({
              queueName: queueName,
              metadata: getMetadata(message),
              payload: getPayload(message),
              remainingTime: remainingTime,
              newLocalStorage: newLocalStorage
            });

          case 4:
            successful = _context5.sent;
            _context5.t0 = successful;

            if (!_context5.t0) {
              _context5.next = 11;
              break;
            }

            _context5.next = 9;
            return sqs.config.region();

          case 9:
            _context5.t1 = _context5.sent;
            _context5.t0 = _context5.t1 !== "localhost";

          case 11:
            if (!_context5.t0) {
              _context5.next = 15;
              break;
            }

            console.info("Deleting message %s from queue %s", message.messageId, queueName);
            _context5.next = 15;
            return sqs.deleteMessage({
              QueueUrl: getQueueURL$1(message),
              ReceiptHandle: message.receiptHandle
            });

          case 15:
            return _context5.abrupt("return", successful);

          case 16:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  }));
  return _handleOneSQSMessage.apply(this, arguments);
}

function getQueueURL$1(message) {
  // Looks like "arn:aws:sqs:us-east-2:123456789012:project-branch__queue"
  var _message$eventSourceA = message.eventSourceARN.match(/arn:aws:sqs:(.*):(.*):(.*)$/).slice(1),
      region = _message$eventSourceA[0],
      accountId = _message$eventSourceA[1],
      queueName = _message$eventSourceA[2];

  return "https://sqs." + region + ".amazonaws.com/" + accountId + "/" + queueName;
} // Gets the short queue name from the ARN.  Used for logging.


function getQueueName(message) {
  var _qualifiedName$match;

  // Looks like "arn:aws:sqs:us-east-2:123456789012:project-branch__queue"
  var qualifiedName = message.eventSourceARN.split(":").pop();
  var queueName = qualifiedName == null ? void 0 : (_qualifiedName$match = qualifiedName.match(/^.*?__(.*)$/)) == null ? void 0 : _qualifiedName$match[1];
  if (!queueName) throw new Error("Could not parse queue name from " + qualifiedName);
  return queueName;
} // Gets the payload from the message.  We rely on the content type, otherwise
// guess by trying to parse as JSON.


function getPayload(message) {
  var _message$messageAttri;

  var type = (_message$messageAttri = message.messageAttributes["type"]) == null ? void 0 : _message$messageAttri.stringValue;
  if (type === "application/json") return JSON.parse(message.body);
  if (type) return message.body;

  try {
    return JSON.parse(message.body);
  } catch (_unused) {
    return message.body;
  }
}

function getMetadata(message) {
  var _message$messageAttri2, _message$messageAttri3;

  var attributes = message.attributes;
  var userId = (_message$messageAttri2 = message.messageAttributes["userId"]) == null ? void 0 : _message$messageAttri2.stringValue;
  var params = Array.from(new URLSearchParams((_message$messageAttri3 = message.messageAttributes["params"]) == null ? void 0 : _message$messageAttri3.stringValue).entries()).reduce(function (all, _ref5) {
    var _extends2;

    var name = _ref5[0],
        value = _ref5[1];
    return _extends({}, all, (_extends2 = {}, _extends2[name] = value, _extends2));
  }, {});
  return {
    jobID: message.messageId,
    groupID: attributes.MessageGroupId,
    params: params,
    queueName: getQueueName(message),
    receivedCount: +attributes.ApproximateReceiveCount,
    sentAt: new Date(+attributes.SentTimestamp),
    sequenceNumber: attributes.SequenceNumber ? +attributes.SequenceNumber : undefined,
    user: userId ? {
      id: userId
    } : null
  };
}

function handleWebSocketRequest(_x, _x2) {
  return _handleWebSocketRequest.apply(this, arguments);
}

function _handleWebSocketRequest() {
  _handleWebSocketRequest = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(event, newLocalStorage) {
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            return _context.abrupt("return", {
              statusCode: 200,
              body: "OK",
              isBase64Encoded: false,
              headers: {}
            });

          case 1:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));
  return _handleWebSocketRequest.apply(this, arguments);
}

function queueJob(_x) {
  return _queueJob.apply(this, arguments);
} // Get the queue URL, and throw Response if queue doesn't exist.

function _queueJob() {
  _queueJob = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(_ref) {
    var payload, dedupeID, groupID, params, queueName, slug, sqs, user, queueURL, contentType, messageBody, message, _yield$sqs$sendMessag, messageId;

    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            payload = _ref.payload, dedupeID = _ref.dedupeID, groupID = _ref.groupID, params = _ref.params, queueName = _ref.queueName, slug = _ref.slug, sqs = _ref.sqs, user = _ref.user;
            _context.next = 3;
            return getQueueURL({
              queueName: queueName,
              slug: slug,
              sqs: sqs
            });

          case 3:
            queueURL = _context.sent;
            contentType = Buffer.isBuffer(payload) ? "application/octet-stream" : typeof payload === "string" ? "text/plain" : "application/json";
            messageBody = Buffer.isBuffer(payload) ? payload.toString("base64") : typeof payload === "string" ? payload : JSON.stringify(payload);
            message = _extends({
              QueueUrl: queueURL,
              MessageBody: messageBody,
              MessageAttributes: _extends({
                "Content-Type": {
                  DataType: "String",
                  StringValue: contentType
                },
                params: {
                  DataType: "String",
                  StringValue: new URLSearchParams(params).toString()
                }
              }, user && {
                userId: {
                  DataType: "String",
                  StringValue: user.id
                }
              })
            }, groupID && {
              MessageGroupId: groupID
            }, dedupeID && {
              MessageDeduplicationId: dedupeID
            });
            _context.next = 9;
            return sqs.sendMessage(message);

          case 9:
            _yield$sqs$sendMessag = _context.sent;
            messageId = _yield$sqs$sendMessag.MessageId;
            !messageId ? process.env.NODE_ENV !== "production" ? invariant(false) : invariant(false) : void 0;
            return _context.abrupt("return", messageId);

          case 13:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));
  return _queueJob.apply(this, arguments);
}

function getQueueURL(_x2) {
  return _getQueueURL.apply(this, arguments);
}

function _getQueueURL() {
  _getQueueURL = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(_ref2) {
    var queueName, slug, sqs, qualified, _yield$sqs$getQueueUr, QueueUrl;

    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            queueName = _ref2.queueName, slug = _ref2.slug, sqs = _ref2.sqs;
            qualified = slug + "__" + queueName;
            _context2.prev = 2;
            _context2.next = 5;
            return sqs.getQueueUrl({
              QueueName: qualified
            });

          case 5:
            _yield$sqs$getQueueUr = _context2.sent;
            QueueUrl = _yield$sqs$getQueueUr.QueueUrl;
            !QueueUrl ? process.env.NODE_ENV !== "production" ? invariant(false) : invariant(false) : void 0;
            return _context2.abrupt("return", QueueUrl);

          case 11:
            _context2.prev = 11;
            _context2.t0 = _context2["catch"](2);

            if (!(_context2.t0 instanceof Error && _context2.t0.name === "AWS.SimpleQueueService.NonExistentQueue")) {
              _context2.next = 18;
              break;
            }

            console.error("No access to queue", qualified);
            throw new Error("No access to queue");

          case 18:
            throw _context2.t0;

          case 19:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2, null, [[2, 11]]);
  }));
  return _getQueueURL.apply(this, arguments);
}

var _swapAWSEnvVars = /*#__PURE__*/swapAWSEnvVars(),
    slug = _swapAWSEnvVars.slug,
    region = _swapAWSEnvVars.region,
    clientConfig = /*#__PURE__*/_objectWithoutPropertiesLoose(_swapAWSEnvVars, ["slug", "region"]); // Entry point for AWS Lambda


function handler(_x, _x2) {
  return _handler.apply(this, arguments);
}

function _handler() {
  _handler = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(event, context) {
    var sqs, urls, newLocalStorage, getRemainingTimeInMillis, messages;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            console.info({
              event: event,
              context: context
            });
            sqs = new SQS(_extends({}, clientConfig, {
              region: region
            }));
            urls = {
              http: process.env.QUEUE_RUN_URL,
              ws: process.env.QUEUE_RUN_WS
            };

            newLocalStorage = function newLocalStorage() {
              return new LambdaLocalStorage({
                sqs: sqs,
                urls: urls
              });
            };

            if (!("requestContext" in event)) {
              _context.next = 16;
              break;
            }

            if (!("connectionId" in event.requestContext)) {
              _context.next = 11;
              break;
            }

            _context.next = 8;
            return handleWebSocketRequest(event, newLocalStorage);

          case 8:
            return _context.abrupt("return", _context.sent);

          case 11:
            _context.next = 13;
            return httpHandler(event, newLocalStorage);

          case 13:
            return _context.abrupt("return", _context.sent);

          case 14:
            _context.next = 31;
            break;

          case 16:
            if (!("url" in event)) {
              _context.next = 22;
              break;
            }

            _context.next = 19;
            return httpHandler(event, newLocalStorage);

          case 19:
            return _context.abrupt("return", _context.sent);

          case 22:
            if (!("Records" in event)) {
              _context.next = 30;
              break;
            }

            getRemainingTimeInMillis = context.getRemainingTimeInMillis;
            messages = event.Records.filter(function (record) {
              return record.eventSource === "aws:sqs";
            });
            _context.next = 27;
            return handleSQSMessages({
              getRemainingTimeInMillis: getRemainingTimeInMillis,
              messages: messages,
              newLocalStorage: newLocalStorage,
              sqs: sqs
            });

          case 27:
            return _context.abrupt("return", _context.sent);

          case 30:
            throw new Error("Unknown event type");

          case 31:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));
  return _handler.apply(this, arguments);
}

var LambdaLocalStorage = /*#__PURE__*/function (_LocalStorage) {
  _inheritsLoose(LambdaLocalStorage, _LocalStorage);

  function LambdaLocalStorage(_ref) {
    var _this;

    var sqs = _ref.sqs,
        urls = _ref.urls;
    _this = _LocalStorage.call(this, {
      urls: urls
    }) || this;
    _this.sqs = void 0;
    _this.sqs = sqs;
    return _this;
  }

  var _proto = LambdaLocalStorage.prototype;

  _proto.queueJob = function queueJob$1(args) {
    var dedupeID = args.dedupeID,
        groupID = args.groupID,
        params = args.params,
        payload = args.payload,
        queueName = args.queueName,
        user = args.user;
    return queueJob({
      dedupeID: dedupeID,
      groupID: groupID,
      params: params,
      payload: payload,
      queueName: queueName,
      sqs: this.sqs,
      slug: slug,
      user: user === undefined ? this.user : user
    });
  };

  return LambdaLocalStorage;
}(LocalStorage);

export { handler };
//# sourceMappingURL=queue-run-lambda.esm.js.map
